## A. Flow-of-funds Analysis


### Data structure

1. how to calculate the flow of funds amount from (generic) branch X to (generic) branch Y:

Table 1.

| bill type    | specifics             | amounts | calculations                                                    |
|--------------|-----------------------|---------|-----------------------------------------------------------------|
| bills sold   | bills of exchange     |       $a$ | $(c + d) - (a + b)$                                               |
|              | telegraphic transfers |       $b$ | amount of interest bills $(d)$                                    |
| bills bought | bills of exchange     |       $c$ | $((c + d) - (a + b)) + d$                                         |
|              | telegraphic transfers |       $d$ | conversions of $(((c + d) - (a + b)) + d)$ into Japanese yen (JPY)|

#### Notes:

> * the above formula `(c + d) - (a + b)` is the standard formula for calculating the flow-of-funds from one branch to another. If you need to understand why `bills sold` need to be subtracted from `bills bought`, consider the following:
>> `bills bought` is the category signifying a positive transfer of funds, as branch X, after buying a bill from an exporter (and thus: paying out an amount of money) in the country of X, sends it on to branch Y, which books it as a `bill for collection` (*daikin toritate tegata* 代金取立手形). At maturity, branch Y collects the money as ‘adverse exchange’ (*gyaku kawase* 逆為替 or, alternatively, *toritate kawase* 取立為替) from an importer in the country in which Y is located, and books the bill to its asset side as a `bill collected`. *In the case of export bills, money thus follows, or in other words, has the same direction of, the goods*. 
In the case of `bills sold`, however, the direction of the transfer is reversed. Branch X sells a bill to an importer of country X (so the latter can remit his payment to an exporter in country Y), and receives an amount of domestic currency for the latter. Branch Y deals with the bill as a `bill payable`, as it will be in charge of the pay-out into to the account of the exporter in the country of Y. Clearly, the latter operation implies a *transfer of funds from branch Y to branch X, or, in other words, a ‘negative transfer’*.
> * the `amount of interest bills (d)` is optional, i.e. is typically zero for flows among most branches, and this for a good reason: typically, interest bills were only sent from liquid centers to liquidity-poor peripheral markets, and this (mostly, but not exclusively) because of their role as finance  bills rather than as bills that contained an underlying trade ('real') transaction. Put simply, they are a function of the degree of the *interest differential* between those branches. One typically finds them as sent from London or New York to Yokohama, Kobe (to a lesser degree), and Shanghai. Especially at times when money was plenty in the global centers and, therefore, when interest rates were low, bankers were eager to draw finance bills on peripheral markets; when credit conditions were more difficult, these operations were cut back. Unfortunately, data and literature on short term capital flows are scarce. Bloomfield (1963) was one of the first to draw attention to the procyclicality of these flows, but much research remains to be done.
> * `((c + d) - (a + b)) + d` speaks for itself: it is the extended version of the above noted formula `(c + d) - (a + b)`, in that it adds interest bills as contracts signifying yet another *positive* flow of funds from branch X to branch Y.
> * the value for the formula `conversions of (((c + d) - (a+ b)) + d) into Japanese yen (JPY)` is important, as it will be used and compared with the value of funds sent from branch Y to branch X; the difference between the two determines the relative exchange position of the branches *vis-a-vis* each other.
>> Sources:
>> * Bloomfield, Arthur I. 1963. *Short-Term Capital Movements under the Pre-1914 Gold Standard*. Princeton Studies in International Finance, no. 11. Princeton, N.J: International Finance Section, Dept. of Economics, Princeton University.


2. Consequently, an adjacency matrix for a a generic branch network with branches X,Y,Z at a point in time `t1` looks as follows:

Table 2.

|   | X  |     |       |   | Y  |     |        |   | Z  |     |      |   |
|---|----|-----|-------|---|----|-----|--------|---|----|-----|------|---|
| **X** | BS | b/e |    -   |  - | BS | b/e | a      |   | BS | b/e | a’   |   |
|   |    | TT  |   -    |  - |    | TT  | b      |   |    | TT  | b’   |   |
|   | BB | b/e |   -   |  - | BB | b/e | c      |   | BB | b/e | c’   |   |
|   |    | TT  |   -   |  - |    | TT  | d      |   |    | TT  | d’   |   |
| **Y** | BS | b/e | a’’   |   | BS | b/e |    -    |  - | BS | b/e | a’’’ |   |
|   |    | TT  | b’’   |   |    | TT  |    -    |  - |    | TT  | b’’’ |   |
|   | BB | b/e | c’’   |   | BB | b/e |    -   |  - | BB | b/e | c’’’ |   |
|   |    | TT  | d’’   |   |    | TT  |    -    |  - |    | TT  | d’’’ |   |
| **Z** | BS | b/e | a’’’’ |   | BS | b/e | a’’’’’ |   | BS | b/e |   -   |  - |
|   |    | TT  | b’’’’ |   |    | TT  | b’’’’’ |   |    | TT  |   -   |  - |
|   | BB | b/e | c’’’’ |   | BB | b/e | c’’’’’ |   | BB | b/e |   -   |  - |
|   |    | TT  | d’’’’ |   |    | TT  | d’’’’’ |   |    | TT  |   -   |  - |

#### Notes:

> * for obvious reasons, branches cannot send amounts to themselves (so-called 'self-loops'). Therefore, these cells have been filled with `-`.
> * as in the above table, amounts sent are expressed by means of generic letters, `a`, `b`, `c`, `d`, `a'`, `b'` etc.
> * `BS` and `BB` stand for respectively 'bills sold' and 'bills bought'. Bills sold represent the remittances (in the form of a bill (`b/e`) )or a telegraphic transfer (`TT`) that importers use for paying their exporting counterpart abroad. Bills bought are bills bought from exporters.
> * The direction is important: it must be remembered that in network analysis, by convention, the direction goes from from the rows to the columns. Hence, the flow from X to Y, which we generically defined as `a` in table 1 can now be found as `a` in the second row, third column, under Y; vice versa, the flows from Y to X, 3 can be found as `a''`, `b''`, etc. on row 6, column 4, under X.



3. An important **methodological novelty** of the book is *the introduction of a measure by means of which we express the relative share of each and every node in closing the bank’s exchange cycle*. We can achieve this by calculating the total amount of funds a branch received from all other branches (i.e. `SUM2`), and deduct that from the total amount of funds sent to all other branches (`SUM1`). Note that the latter gives us a (positive or negative) number for any branch in any semester. This number —which is, *by definition*, the inverse of a branch’s exchange position at any semester— functions as the indicator of a branch’s contribution to providing exchange cover on the branch network. Branches with a positive number are ‘givers’, i.e. they enable other branches to accumulate net surpluses. Vice versa, branches with a negative number are 'takers' or, in extreme cases, ‘sinks’, causing other branches to experience a drain on their capital. We call the ranking of every branch at any semester the ‘flow-of-fund index’ (`FoF-index`).

This can be done for all points in time `t1`, `t2`, `t3`, etc. Calculating the `FoF-index` of branch X in a simple 3-branch network (X, Y, Z) at time `t1` can be done as follows:

|       | X                                    | Y                                     | Z                                     |                      |
|-------|--------------------------------------|---------------------------------------|---------------------------------------|----------------------|
| **X** |                                      | X→Y : (bills bought minus bills sold) | X→Z : (bills bought minus bills sold) | **SUM1:(X→Y)+(X→Z)** |
| **Y** | Y→X: (bills bought minus bills sold) |                                       | Y→Z: (bills bought minus bills sold)  |                      |
| **Z** | Z→X: (bills bought minus bills sold) | Z→Y: (bills bought minus bills sold)  |                                       |                      |
|       | **SUM2:(Y→X)+(Z→X)**                 |                                       |                                       |                      |


4. Having calculated the `FoF-index` of *every* branch vis-a-vis the branch network at *all* points in time, we can proceed with a **time series**:

|       | t1                  | t2  | t3  | ... |
|-------|---------------------|-----|-----|-----|
| **X** | (X→Y+X→Z)-(Y→X+Z→X) | ... | ... |     |
| **Y** | (Y→X+Y→Z)-(X→Y+Z→Y) | ... | ... |     |
| **Z** | (Z→X+Z→Y)-(X→Z+Y→Z) | ... | ... |     |

The latter's visualization is graph 1 (below)

### Ethnographic relevance

> * when plotting, in a time series, the differential between a) funds sent from X to Y and b) funds sent from Y to X, we inadvertently *yet consciously* point out the *necessary* existence of a 'negative' `FoF-index` of certain branches versus others (either X or Y) and, by extension, the possibility of a negative `FoF-index` of a certain branch *vis-a-vis* the aggregated branch network. This may seem obvious and, indeed, *it is*: bankers at the time complained relentlessly about certain branches that they considered to be chronic 'withdrawers' of funds. In the vocabulary and thinking of social network analysis (SNA), however, it is not that simple. As the theory stands now, SNA does not easily accept the possibility of 'negative flows' (as, for instance, in the case of a banking customer using an overdraft facility with his local bank). In the book manuscript, I thought it to be important to be true to the contemporary problem awareness, and have attempted to allow the possibility of negative flows in the analysis and visualizations. See graph 1 below.

Graph 1: YSB branches FoF-index - a time series, 1893-1908

![YSB branches exchange position - a time series](/YSB_centrality1.png)

Source: [own data and analysis](https://plot.ly/~michaelschiltz/13/ysb-branches-centrality-1893-1908/)

*Legend*: Y: Yokohama Head Office 横浜本店; K: Kobe 神戸; L: London; NY: New York LY: Lyon; SF: San Francisco; HW: Hawai; S: Shanghai 上海; H: Hankow 漢口; B: Mumbai (Bombay); HK: Hong Kong 香港; T: Tokyo 東京; N: Nagasaki 長崎; TJ: Tianjin 天津; NZ: Niuzhang 牛荘; P: Beijing (Peking) 北京; D: Dairen 大連; LI: Liaoyang 遼陽; M: Mukden 奉天; LS: Lushun 旅順; A: Andong 安東; Z: Yantai (Chefoo) 芝罘; O: Osaka 大阪; TL: Tieling 鐵嶺; C: Changchun 長春; CBI: correspondent banks (international); CBD: correspondent banks (domestic). 


### Rounding

> * importantly, amounts were rounded *to the ones*. This is quite different from earlier analyses, which chose to round to the thousands. In itself, however, it was the only way to come to conclusive findings with respect to the question whether hedging strategies were effectively adopted or not.

### Conversions into Japanese yen

> * Exchange rates were taken from the  ["Historical statistics - Exchange rates" page of the Bank of Japan](http://www.imes.boj.or.jp/hstat/data/ferdd/index.html); this page contains both a data source (in .CSV), and an [explanatory note](http://www.imes.boj.or.jp/hstat/data/ferdd/note_ferdd.html); see [here for English](http://www.imes.boj.or.jp/english/hstat/data/ferdd/note_ferdd.html)
> * I have used the monthly average value as base for calculations (unfortunately, end-of-month rates are not included in the BOJ database)

## B. Interest Bills

A particular point of attention must be reserved for the so-called `interest bills`, or *ritsuki tegata* 利付手形. For a host of reasons, they pose some serious interpretative hurdles for the financial historian. Concretely, these bills were, at least for the period 1898-1908, not included in the Midterm Reports’ flow data, but treated as a particular category under `statement of loans and bills discounted` (*kashikin oyobi tegata waribiki no koto* 貸金及ビ手形割引ノ事). This exclusion from the `statement of the amount of bills sent and received` has caused considerable misunderstandings among students of Yokohama Specie Bank foreign exchange operations. 

> * Notably Taira, who pioneered the network approach to YSB flow-of-funds, surmised that interest bills were listed in both ‘statement of loans and bills discounted’ and the ‘statement on foreign exchange holdings and movements’. Hence, he omitted them from his analysis as it would otherwise amount to double-counting the data. Ishii, on the other hand, has convincingly argued that the interest bill data cannot have been included in the statement on foreign exchange holdings and movements, as Japan’s trade deficit with Great-Britain in this period should in any case have resulted in very large transfers of funds from Great-Britain to Japan (as exports from Great-Britain to Japan would have been financed by bills bought in London and sent to Yokohama and Kobe for collection). Consequently, Taira’s analysis, which seems to show a reverse flow of funds from Japan to Great-Britain, must be mistaken. 
> * Yet another interpretation can be found in Bak (Park). In his view, interest bills functioned as remittances (*sōkin* 送金) of foreign exchange which were sent  by the branch/office in charge of collection (*toritate-ten* 取立店) to the branch/office that had purchased the bill (*kaitori-ten* 買取店). In other words, Bak believes that interest bills were a means of settling (squaring) accounts between branches (in Japanese referred to as remitting (*kaikin* 回金) (as opposed to reimbursing)). In this view, including the interest bills in the flow of funds also amounts to double-counting, yet in a way different from Taira’s interpretation. However, as is clear from e.g. interest bills handled by the New York office, *interest bills were also used for trade transactions*.
> * Based on Nishimura's early discussion (see the description in the book), we suspect that their classification under `statement of loans and bills discounted` hints to their nature as finance bills rather than bills designating an underlying trade transaction (the latter being called 'real bills' at the time).
> * The consequences of such conjecture may be profound. As we point out in the book, it hints to the existence of a late nineteenth century **carry trade**. We possess at least descriptive evidence of the latter:

>> "For bills related to East-Asia, one bookkeeping manual from 1907 provides the following narrative evidence: “The interest rate in London is, on average, between 3 and 4 per cent. [The international exchange banks] there purchase ‘Eastern bills’ [i.e. interest bills] on India, China and Japan. Given that the interest [on the latter] is normally around 6%, and given that they purchase Eastern bills by means of low-interest London funds, they are obviously running a very profitable business.” 

>This was certainly so after the Russo-Japanese War. According to the same source: 

>>“The interest on interest bills to East-Asia is normally 6%, but last year, due to problems in Russo-Japanese relations, the rate was increased to 7%”. In other words, even when estimating the yearly cost of London acceptance credit to be around 5% in the 1900s, arbitraging must have been a lucrative affair. And indeed, the share of interest bills in the total ‘bills sent’ portfolio of YSB London is very high (consistently more than 60% after 1898)." 石川由郎. 1907. 『英国為替銀行ニ関スル復命書』. 三井銀行. P. 67; p. 76.

>> Sources:
>> * Ishii Kanji 石井寛治. 1999. *Kindai nihon kin’yū-shi josetsu* 『近代日本金融史序説』. 東京大学出版会. P. 250-251; 
>> * Ishii Kanji. 1994. “Japanese Foreign Trade and the Yokohama Specie Bank, 1880-1913”, in Olive Checkland, Shizuya Nishimura, and Norio Tamaki (eds.), *Pacific Banking, 1859-1959: East Meets West*. New York: St. Martin’s Press. Pp. 22-23. 
>> * Taira Tomoyuki 平智之. 1984. 「第1次大戦前の国際金本位制下における横浜正金銀行–日銀の兌換制維持政策との関連において-上-.」 『金融経済』, no. 208 (October): p41–81. http://ci.nii.ac.jp/naid/40000792001; 
>> * Taira Tomoyuki 平智之. 1984. 「第1次大戦前の国際金本位制下における横浜正金銀行–日銀の兌換制維持政策との関連において-下-.」 『金融経済』, no. 209 (December): p1–27. http://ci.nii.ac.jp/naid/40000792007. 
>> * Bak Jun Geon 朴埈健. 1992. 「産業資本成立期における横浜正金銀行の資金循環構造–利付為替手形の処理問題を中心として.」 『経済論究』, March, p. 147–162.

Yoshiwara Tatsuno has focused on the fact that interest bills were not only sent from liquid centers to non-liquid regions, but also *among liquid centers*. This is an element that I have left out of the database because these amounts are dwarfed by the former (esp. interest bills sent from London to Japan). He may, however, have a point. At least the *Economist* mentions the role of finance bills arriving from France and NY in the early twentieth century (see the book manuscript). Admittedly, it is not clear whether these finance bills were necessarily interest bills, but our conjecture in the book points to the plausibility hereof.
>> Sources:
>> * 葭原 達之. 1979. 「横浜正金銀行における「連合的営業法」の創設と展開.」 『経営史学』 13 (3):p41–60. http://ci.nii.ac.jp/naid/40000827988; 
>> * 葭原達之, and 記念論文集委員会. 1986. 「横浜正金銀行における「分立的営業法」の成立とその意義.」 In 『工藤良平教授記念経済学論文集』, 197–229. 弘前: 弘前大学.


## C. Other Balance Sheet Data

see [here](https://github.com/michaelschiltz/even-keel/blob/master/2.%20data%20inclusion%20and%20exclusion.md#balance-sheet-data-stock-data)
