## "Forensic Accounting"

1. As indicated in the *Making of the Database*-chapter, an important key to the successful analysis of exchange banking lies with the discovery of what mattered to bankers at the time, more specifically what they perceived a) crucial to the bank's smooth functioning, b) acceptable in terms of risks to be taken, and so on. It would therefore be a mistake to make claims about turnover, profitability etc, without getting one's definitions straight. In one example, we have pointed out peculiarities pertaining to interest bills, or *ritsuki tegata* 利付手形. In another, Nishimura clarified the changing nature of bill finance after the late 1880s. Importantly, his argument was based on *inductive reasoning*, so it can only be [judged in terms of its relative probability](https://en.wikipedia.org/wiki/Inductive_reasoning), but the lack of available data made the use of descriptive evidence into the *inevitable* way to arrive at arguably the most plausible explanation of a host of counterintuitive trends (for example the tendency for bill usance to lengthen once more after it had been brought down around 1880).

> * Reference: Nishimura, Shizuya. 1971. *The Decline of Inland Bills of Exchange in the London Money Market, 1855-1913*. London: Cambridge University Press.

2. Inductive, or, if one wants, 'forensic' reasoning has come to bear significantly on the calculations underlying our findings. As noted in the book:

> [...] how did nineteenth century exchange business work? [...] ? As we have seen, bank branches sent both ‘bills sold’ (to importers in their country of location) and ‘bills bought’ (from exporters in their country of location) to each other. Can we conveniently aggregate these amounts in order to calculate the relative exchange position of certain branches within our network? Although this is certainly tempting, and may even be legitimate depending on the research question, for instance in the case of measuring activity at branches, it is problematic in view of the accounting technicalities that were valid at the time. 
> As noted by Ishii (still the most authoritative source on this matter), bills bought is the category signifying a positive transfer of funds, or better, the transfer of an asset, as branch X, after buying a bill from an exporter in the country of X, sends it on to branch Y, which books it as a ‘bill for collection’ (*daikin toritate tegata* 代金取立手形). At maturity, it collects the money as ‘adverse exchange’ (*gyaku kawase* 逆為替 or, alternatively, *toritate kawase* 取立為替) from an importer in the country in which Y is located, and books the bill to its asset side as a ‘bill collected’. In the case of export bills, money thus follows, or has the same direction of, the goods. In the case of bills sold, however, the direction of the transfer is reversed. Branch X sells foreign exchange to an importer of country X, so the latter can remit his payment to an exporter in country Y. The bill is booked to the credit of branch X.  Branch Y has to deal with the bill as a ‘bill payable’ (debit), as he will have to credit the account of the exporter in the country of Y. The latter operation implies a transfer of funds from branch Y to branch X, or, in other words, a ‘negative transfer’.

>> * Source: Ishii Kanji 石井寛治. 1999. *Kindai nihon kin’yū-shi josetsu* 『近代日本金融史序説』. 東京大学出版会, esp. pp. 245 ff.

3. In its most rudimentary form, the direction of the flow of funds with the indication of a positive versus negative fund flow (+/-) between two branches in different countries looks as follows:

Image 1: 

![bills workflow in an exchange bank](/trade_finance_model.png)

> * After: 鈴木俊夫. 2005. 「オリエンタル銀行設立の一齣」. 『三田商学研究』 48 (5): 41–61. http://ci.nii.ac.jp/naid/120000800144. P. 50.
Compare as well: Suzuki, Toshio. 2012. “The Rise and Decline of the Oriental Bank Corporation, 1842–84.” In *The Origins of International Banking in Asia*, edited by Shizuya Nishimura, Toshio Suzuki, and Ranald C. Michie, 86–106. Oxford University Press.
http://www.oxfordscholarship.com/view/10.1093/acprof:oso/9780199646326.001.0001/acprof-9780199646326-chapter-4. P. 93
> * Note: as the reader may realize, the inclusion of a remitter respectively remittee is strictly speaking not required.  Importers and exporters can deal directly with a branch of an international bank. We do include them, however, in order to allow for a situation in which these dealings were mediated by yet another institution. Historically, this was the case in India, where the Presidency Banks played the role of middlemen. In the metropolis, one may think of the role of clearing and merchant banks, whose ‘signing across’ (an expression of the promise to pay the bills at maturity) raised a bill’s creditworthiness, so the latter could easily be sold in the London discount market. Their ‘reputability’ was, in other words, integral to the smooth functioning of the mechanism of bill finance.
See: Brunyate, James Bennett. 1900. *An Account of the Presidency Banks*. Office of the Superintendent of Government Print.
Suzuki, Toshio. 2012. “The Rise and Decline of the Oriental Bank Corporation, 1842–84.” In *The Origins of International Banking in Asia*, edited by Shizuya Nishimura, Toshio Suzuki, and Ranald C. Michie, 86–106. Oxford University Press.
http://www.oxfordscholarship.com/view/10.1093/acprof:oso/9780199646326.001.0001/acprof-9780199646326-chapter-4. P. 92.
