## The Accounts: Problems of Analysis

### Sources:
> As noted in Frank King's *The History of the Hongkong and Shanghai Banking Corporation* (Vol. I, p. 34),

>> `Accounting, at least accounting as practised on the China coast, being an inexact art, the nature of which changed considerably over the period, the published figures are difficult to interpret and as a time series they contain serious deficiencies.`

> The same observation holds for the Yokohama Specie Bank accounts used for the monograph (‘Midterm’ reports, called *hanki-hōkoku* 半季報告, or, originally, *kōkajō* 考課状 (literally ‘assessment report’), notably for the period January 1893 until July 1908.). Published, relatively openly, on a semestrial basis and distributed among shareholders, as was the case with most exchange banks at the time, they provide an insight in accumulated assets and liabilities for each 6-month period. Their importance for our understanding of the activities and management of a late nineteenth century exchange bank can hardly be overestimated. Highly reliable for, especially, the period around 1900, they provide the necessary shortcut for inter-branch connections that would otherwise be painstaking to reconstruct, for instance on the basis of the ledgers of each individual branch.

> In their most basic form, the Midterm reports almost all contain the following items:
>> * 1. a balance sheet listing the bank’s main assets and liabilities (mostly included as fold-out in the back-cover) (*kashakiri-taishōhyō* 貸借対照表)
>> * 2. a statement on the bank’s shareholders fund; its reserve fund(s) (Jpn. *kabukin shotsumitatekin oyobi junbikin no koto* 株金諸積立金及ビ準備金ノ事)
>> * 3. a statement on deposits (Jpn. *yokin no koto* 預金ノ事)
>> * 4. a statement of loans and bills discounted (Jpn. *kashikin oyobi tegata waribiki no koto* 貸金及ビ手形割引ノ事)
>> * 5. **a statement on its foreign exchange holdings and movements (Jpn. *kaigai kawase no koto* 海外為替ノ事)**
>> * 6. **a statement on inland bills (*naikoku kawase no koto* 内国為替ノ事)**
>> * 7. a statement on rediscounting activity (*sai-waribiki tegata no koto* 再割引手形ノ事)
>> * 8. a statement on loans payable (*kari-irekin no koto* 借入金ノ事)
>> * 9. a statement on holdings of silver and gold money; cash on deposit (*kingin zaidaka oyobi yotakukin no koto* 金銀在高及ビ預託金ノ事) 
>> * 10. a statement on holdings of public loans and other securities (*kōsai shōsho no koto* 公債證書ノ事)
>> * 11. a statement on property (*shoyūbutsu no koto* 所有物ノ事)
>> * 12. a statement on holdings of gold and silver bullion and foreign currencies (*jigane gin oyobi gaikoku ka no koto* 地金銀及ビ外国貨幣ノ事)
>> * 13. a statement of income derived from the selling and buying of stocks (*kabushiki baibai jōju no koto* 株式売買譲受ノ事)
>> * 14. a profit and loss statement (*son’eki kin no koto* 損益金ノ事); and 
>> * 15. a statement with respect to the allocation of profits (*riekikin bunpaihō no koto*  利益金分配方ノ事)

> For obvious reasons, the balance sheet (1) represents the gist of the bank’s assets and liabilities for each respective semester. It aggregates the balance data that one can find broken down under categories (2)(3)(4)(7)(8)(9)(10)(11)(12)(13)(14)(15). *Note, however, that (5) and (6) are not included here*. The latter are `flow data` (as opposed to `stock data`), meaning that they consist of origin-destination data documenting the flows or migration of assets acquired and liabilities incurred, within the bank’s branch network, and, importantly, *within a clearly delineated time interval* (accumulated assets/liabilities, or 'carried over from former semesters' are excluded). Because these data comprise both assets and liabilities, they cannot possibly be conveniently allocated under one of these categories. Rather, they help identify risks in interbranch dealings, in our case typically related to difficulties with regard to finding `matching funds`, the relative `exchange position` of a branch within the network and so on. As we will see later, flow data are particularly revealing when assessing the characteristics of specific bank management systems. Concretely, they document, on the basis of the distinction between `bills bought` and `bills sold`, how branches exchange liabilities and assets among each other, and thus make it, in principle, possible to identify trade patterns between countries and/or regions.

### Interpretative hurdles; how reliable are the published accounts?

> As bookkeeping technicalities are covered [elsewhere](https://github.com/michaelschiltz/even-keel/blob/master/1.%20database%20architecture.md#notes), we confine our discussion here to the *reliability* of sources. As can be expected, the midterm reports are to a certain extent a function of the political positioning of Japan and its institutions. As we will discuss further below, this has had ―ironically― its fortunate implications for the discussion here. At a time when the country was factually too weak to unilaterally claim its place in the world order, YSB resorted to a sort of ‘news propaganda’ (compare, in this respect, the ideas of [Akami Tomoko](https://www.amazon.com/Japans-Propaganda-Reuters-Northeast-1870-1934/dp/9089791027)) that was carefully geared to the information-hungry investor in London, Paris, or any other global financial market. As a result, early mid-term reports for 1893-1908 are very extensive, sensitively reflecting the market conditions that its branches faced, documenting the political and economic events that were to explain any volatility in its business record that to any extent could be considered extraordinary, and so on. 

> Put differently, early reports cleverly play into the discourse of the European (mostly British) liberal economic ideas by which observers since the 1930s have wanted to remember the first gold standard period. It is beyond doubt that such reports would be followed by leading financial outlets of the day: subtly, but convincingly, YSB demonstrated to an international readership that its knowledge of the expanding Asian market, bolstered by its presence in all but the smallest trading centers in the region, was second to none, apart perhaps from the Hongkong and Shanghai Banking Corporation.

> I furthermore note YSB managers' preoccupation with 'overt transparency', as noted in internal discussions. The precision of the coverage in the reports between 1893 and 1908 was a topic at the first Meeting of the Managers of Asian Branches of YSB (*tōyō shitenchō kaigi* 東洋支店長会議; April 1908 at the Yokohama Head Office). Concretely, several managers worried that its foreign competitors might undertake a translation of the Mid-term reports, causing valuable “business secrets” of the bank to be “leaked” (*naibu no himitsu wo morasu osore ari* 内部ノ秘密ヲ洩ラス恐レアリ). 横濱正金銀行. 19--. 『東洋支店長会議録』. [横浜正金銀行]. http://ci.nii.ac.jp/ncid/BN04887997. P. 310. For HSBC too, secrecy was a continuing issue, as Frank King testified.

> Behind the published accounts, there also was a process of **auditing**. After all, the semi-annual accounts were not a statement of the position of the Bank on the date stated. The tyranny of distance still being real, even after adoption of the telegraph, bank branches would close their books on different dates in order for their information to reach the Head Office in time. Clearly, the auditors reports (*kansayaku yōroku* 監査役要録) had quite some things to be concerned with: the rate at which accounts were 'taken over', the time lag involved in integrating them with Head Office Accounts,the local (i.e. branch-specific) assessment of non-performing loans, the valuation of public securities held etc.

> This is not to say there may not have been a mismatch between the bank's official accounts and public perception. Judging from contemporary journalistic sources (the *Economist*, the *Investors' Monthly Manual*, or, for that matter, Japanese sources of financial journalism), shareholders/investors/observers made their own estimates of the so-called 'inner reserves'and the valuation of the securities held against the reserve fund. I suppose much depended on how these people evaluated the Bank's ongoing policy with respect to handling shifts in exchange rates, as also the discussions of the `even keel` in the *North China Herald* prove (see the monograph). However, this also reinforces the assumption that the mismatch should not have been too wide in order to remain credible after all. *Confidence* was (and remains) one of a bank's most important assets, and the latter was arguably derived from the Bank's published figures. As in [Akerlof's famous thought experiment](https://doi.org/10.2307/1879431), banks may have been incentivized to counteract information asymmetry by adopting (self-)certifying measures as reputation and prestige through transparency.
